<?php

namespace Drupal\blocktabs\Form;

use Drupal\Core\Entity\EntityForm;
use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Base form for blocktabs add and edit forms.
 */
abstract class BlocktabsFormBase extends EntityForm {

  /**
   * The entity being used by this form.
   *
   * @var \Drupal\blocktabs\BlocktabsInterface
   */
  protected $entity;

  /**
   * The block tabs entity storage.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected $entityStorage;

  /**
   * Constructs a base class for blocktabs add and edit forms.
   *
   * @param \Drupal\Core\Entity\EntityStorageInterface $entity_storage
   *   The block tabs entity storage.
   */
  public function __construct(EntityStorageInterface $entity_storage) {
    $this->entityStorage = $entity_storage;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager')->getStorage('blocktabs')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function form(array $form, FormStateInterface $form_state) {

    $form['label'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Blocktabs name'),
      '#default_value' => $this->entity->label(),
      '#required' => TRUE,
    ];

    $form['name'] = [
      '#type' => 'machine_name',
      '#machine_name' => [
        'exists' => [$this->entityStorage, 'load'],
      ],
      '#default_value' => $this->entity->id(),
      '#required' => TRUE,
    ];

    $form['#tree'] = FALSE;
    $form['settings'] = [
      '#type' => 'details',
      '#title' => $this->t('Tabs settings'),
    ];

    $plugin_manager = \Drupal::service('plugin.manager.sdc');
    $components = $plugin_manager->getAllComponents();
    $component_options = [];
    foreach ($components  as $component) {
      $metadata = $component->metadata ?? [];
	 // \Drupal::messenger()->addMessage("component_options:" .var_export($metadata,true));
	  $group = $metadata->group ?? "";
      $component_id = $component->getPluginId();
      if ($group === "blocktabs") {
        $component_options[$component_id] = $metadata->name;
	  }
    }
	
    $default_component = $this->entity->getComponent();
    if (empty($default_component)) {
      $default_component = 'blocktabs:tabs-basic';
    }
	\Drupal::messenger()->addMessage("component_options:" .var_export($component_options,true));
    $form['settings']['component'] = [
      '#type' => 'radios',
      '#title' => $this->t('Select SDC component used for render'),
      '#default_value' => $default_component,
      '#options' => $component_options,
    /*  '#options' => [
        'blocktabs:tabs-basic' => $this->t('Basic tabs'),
        'blocktabs_jquery_ui:tabs-default' => $this->t('Default tabs(jQuery ui)'),
        'blocktabs_jquery_ui:tabs-vertical' => $this->t('Vertical tabs(jQuery ui)'),		
        'blocktabs_jquery_ui:accordion' => $this->t('Accordion(jQuery ui)'),
      ], */
    ];	
    return parent::form($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    parent::save($form, $form_state);
    $form_state->setRedirectUrl($this->entity->toUrl('edit-form'));
  }

}
